<?php

namespace App\Controller;

/*
 * Copyright (C) 2020 Daniel Siepmann <coding@daniel-siepmann.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

use App\Persistence\Entries;
use App\Service\ActiveEntry;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

class TimeController extends AbstractController
{
    /**
     * @var ActiveEntry
     */
    private $activeEntry;

    /**
     * @var Entries
     */
    private $entries;

    public function __construct(
        ActiveEntry $activeEntry,
        Entries $entries
    ) {
        $this->activeEntry = $activeEntry;
        $this->entries = $entries;
    }

    public function index(): Response
    {
        return $this->render('time/index.html.twig', [
            'entry' => $this->activeEntry->get(),
            'entries' => $this->entries->get(10),
        ]);
    }

    public function start(Request $request): Response
    {
        $this->activeEntry->startNew(
            $request->request->get('title')
        );

        return $this->redirectToRoute('index');
    }

    public function stop(): Response
    {
        if ($this->activeEntry->get()->isRunning() === false) {
            return $this->redirectToRoute('index');
        }

        $this->activeEntry->stopRunning();

        return $this->redirectToRoute('index');
    }
}
