<?php

namespace App\Service;

/*
 * Copyright (C) 2020 Daniel Siepmann <coding@daniel-siepmann.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

use App\Entity\Entry;
use App\Persistence\Entries;
use Symfony\Component\HttpFoundation\Session\SessionInterface;

class ActiveEntry
{
    /**
     * @var SessionInterface
     */
    private $session;

    /**
     * @var Entries
     */
    private $persistence;

    public function __construct(
        SessionInterface $session,
        Entries $persistence
    ) {
        $this->session = $session;
        $this->persistence = $persistence;
    }

    public function startNew(
        string $title
    ): Entry {
        $entry = new Entry(
            $title
        );
        $entry->start();

        $this->session->set('runningEntry', $entry);

        return $entry;
    }

    public function stopRunning(): void
    {
        $entry = $this->get();

        $entry->stop();

        $this->persistence->add($entry);

        $this->session->remove('runningEntry');
    }

    public function get(): Entry
    {
        return $this->session->get('runningEntry') ?? new Entry();
    }
}
